---
title: "The Research Software Alliance (ReSA) and the Community Landscape"
date: 2020-03-11
author: "Daniel S. Katz, Michelle Barker, Paula Andrea Martinez, Hartwig Anzt, Alejandra Gonzalez-Beltran, and Tom Bakker"
---


ReSA’s mission is to bring research software communities together to collaborate on the advancement of research software. Its vision is to have research software recognized and valued as a fundamental and vital component of research worldwide. Given our mission, there are multiple reasons that it's important for us to understand the landscape of communities that are involved with software, in aspects such as preservation, citation, career paths, productivity, and sustainability. One of these reasons is that ReSA seeks to be a link between these communities, which requires identifying and understanding them. We want to be sure that there aren't significant community organizations that we don't know about to involve in our work. Also, identifying where there are gaps will help us create the opportunities and communities of practices as required.





When thinking about these communities, it's clear that in addition to those that focus on software, there are others for which software is just a small part of their interest. Some examples are communities that focus on open science, reproducibility, roles and careers for people who are less visible in research, publishing and review, and other types of scholarly products and digital objects. ReSA also wants to define how we fit and interact with that  broader scholarly landscape.





### How was this work undertaken?





In September 2019, a [ReSA taskforce](http://www.researchsoft.org/resa-taskforces-join-us/) came together to map the software community landscape, consisting of the authors of this blog. This group distributed a [survey](https://docs.google.com/forms/d/1kftKvGAHXIFButQ47Q3WoSCBT0v789tuksiLQkekzt4/viewform?edit_requested=true) to [ReSA google group](https://groups.google.com/forum/#!forum/research-software-alliance) members to identify other groups interested in software. Other useful sources included:







* [Netherlands eScience Center: Awesome-research-software-registries](https://github.com/NLeSC/awesome-research-software-registries/blob/master/README.md) by Jurriaan Spaaks

* [eResearch-meeting-list](https://github.com/jamespjh/eResearch-meeting-list/tree/master) by James Hetherington

* [International RSE groups](https://rse.ac.uk/community/international-rse-groups/) by the [Research Software Engineering (RSE) Association](https://rse.ac.uk/)

* [Open Science Grassroots Community Networks](https://docs.google.com/spreadsheets/d/1LNF5_bOkRV-RLIF4HYmu-gOemIa4IdfXEer89fM-Vy8/edit#gid=0), a consortium of 120 networks 

* [In which journals should I publish my software?](https://www.software.ac.uk/which-journals-should-i-publish-my-software) by Neil Chue Hong





The taskforce then met to consider the results and how to analyze them. The [ReSA list of research software communities](https://docs.google.com/spreadsheets/d/15JHqOxR4HIKHYe821IPvbxIuXP1zMjXKGEIJwB-GPqE/edit#gid=0) is now publicly available as a living community resource, with the version of this list used by the ReSA taskforce in February 2020 and a copy of this post archived in [Zenodo](https://doi.org/10.5281/zenodo.3699950). Suggested additions or corrections are welcome by making comments in the [list](https://docs.google.com/spreadsheets/d/15JHqOxR4HIKHYe821IPvbxIuXP1zMjXKGEIJwB-GPqE/edit#gid=0).





Some of the issues we've had in assembling this list are:

* How much interest in software does an organization need to have to be listed?

* When is an organization sufficiently research focused to be included?

* What momentum/scale does an organization need to have so that we consider it relevant in the global picture? 

On the other hand, once we started adding entries to the list, for many we found that we immediately thought of other similar organizations that should be added. For example, some organizations have a geographic aspect, and this led us to think of other similar organizations with different geographic aspects, such as all the national and regional RSE associations.





### What did we learn?





There were a range of interesting outcomes of the analysis:





* There are many, many communities that support research software, emphasizing the need for a coordinating organization such as ReSA. The importance of community development is captured in articles such as [Community Organizations: Changing the Culture in Which Research Software is Developed and Sustained](https://arxiv.org/abs/1811.08473) by Daniel S. Katz et al., which provides an overview of key groups and discusses opportunities to leverage their synergistic activities.

* There is an increasing (and wide) range of community initiatives. For example, the [Open Science Grassroots Community Networks](https://docs.google.com/spreadsheets/d/1geYQLpJQtzPbhN3UZGSqPGFKNIF-hqXd7PGrwZJzasA/edit#gid=0) list has evolved into the Community of Open Scholarship Grassroots Networks (COSGN), whose networks communicate and coordinate on topics of common interest. COSGN has submitted an [NSF proposal](https://osf.io/preprints/metaarxiv/d7mwk) to formalize governance and coordination of the networks to maximize impact and establish standard practices for sustainability. 

* The increasing focus on open software makes it hard to separate research and non-research initiatives. As per the points above, it is very hard to define which initiatives are part of the research software community, and which aren’t.

* Some organizations that were originally data-centric now include a software focus. For example, the Research Data Alliance now includes the [Software Source Code Interest Group](https://www.rd-alliance.org/groups/software-source-code-ig), which provides a forum to discuss issues on management, sharing, discovery, archiving, and provenance of software source code.





### What are the next steps?





We invite readers to continue to add or make corrections to the [ReSA list of research software communities](https://docs.google.com/spreadsheets/d/15JHqOxR4HIKHYe821IPvbxIuXP1zMjXKGEIJwB-GPqE/edit#gid=0) by making comments in the list, which will continue to be curated by ReSA. We are also interested to hear from community members who would like to engage with us in writing a landscape paper based on further analysis and work. This could address questions such as what are the axes that create the space, where do the currently-known organizations fit in the space, and are there gaps where no organization is currently working? We also invite readers to consider involvement in other ReSA activities, including [Taskforces](http://www.researchsoft.org/resa-taskforces-join-us/).





### Conclusion





The ever-growing number of constituents of the research software community both reflects and demonstrates the increasing recognition of research software. The research software community is now a complex ecosystem comprised of a wide variety of organizations and initiatives, some of which are community networks themselves. Collaboration and coordination across these initiatives is important, to enable the broader community to work together to achieve bigger goals.





ReSA aims to coordinate across these efforts to leverage investments, to achieve the shared long-term goal of research software valued as a fundamental and vital component of research worldwide. Join the [ReSA google group ](https://groups.google.com/forum/#!forum/research-software-alliance) to stay up-to-date on our activities.







